@@ -1,16 +1,21 @@
-use super::scheme::ShardScheme;
-use crate::shard::ResumeSession;
-use std::{collections::HashMap, sync::Arc};
+use crate::{cluster::ShardScheme, shard::ResumeSession};
+use std::{
+    collections::HashMap,
+    fmt::{Debug, Formatter, Result as FmtResult},
+    sync::Arc,
+};
 use twilight_gateway_queue::Queue;
+use twilight_model::gateway::payload::outgoing::update_presence::UpdatePresencePayload;
 
 /// Built configuration for a [`Cluster`].
 ///
 /// [`Cluster`]: crate::Cluster
-#[derive(Debug)]
 pub struct Config {
-    pub(super) shard_scheme: ShardScheme,
     pub(super) queue: Arc<dyn Queue>,
     pub(super) resume_sessions: HashMap<u64, ResumeSession>,
+    pub(super) shard_presence:
+        Option<Box<dyn Fn(u64) -> Option<UpdatePresencePayload> + Send + Sync + 'static>>,
+    pub(super) shard_scheme: ShardScheme,
 }
 
 impl Config {
@@ -30,6 +35,17 @@ impl Config {
     }
 }
 
+impl Debug for Config {
+    fn fmt(&self, f: &mut Formatter<'_>) -> FmtResult {
+        f.debug_struct("Config")
+            .field("queue", &self.queue)
+            .field("resume_sessions", &self.resume_sessions)
+            .field("shard_presence", &"<Fn>")
+            .field("shard_scheme", &self.shard_scheme)
+            .finish()
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::Config;
