@@ -186,6 +186,7 @@ impl ShardBuilder {
             session_id: None,
             sequence: None,
             tls: None,
+            ratelimit_payloads: true,
         })
     }
 
@@ -202,6 +203,7 @@ impl ShardBuilder {
     /// [`EventTypeFlags::SHARD_PAYLOAD`] is enabled.
     ///
     /// [`EventTypeFlags::SHARD_PAYLOAD`]: crate::EventTypeFlags::SHARD_PAYLOAD
+    #[must_use = "has no effect if not built"]
     pub const fn event_types(mut self, event_types: EventTypeFlags) -> Self {
         self.0.event_types = event_types;
 
@@ -209,6 +211,7 @@ impl ShardBuilder {
     }
 
     /// Set the URL used for connecting to Discord's gateway
+    #[must_use = "has no effect if not built"]
     pub fn gateway_url(mut self, gateway_url: Option<String>) -> Self {
         self.0.gateway_url = gateway_url.map(String::into_boxed_str);
 
@@ -220,6 +223,7 @@ impl ShardBuilder {
     ///
     /// Default is a new, unconfigured instance of an HTTP client.
     #[allow(clippy::missing_const_for_fn)]
+    #[must_use = "has no effect if not built"]
     pub fn http_client(mut self, http_client: Arc<HttpClient>) -> Self {
         self.0.http_client = http_client;
 
@@ -255,6 +259,7 @@ impl ShardBuilder {
     /// # Ok(()) }
     /// ```
     #[allow(clippy::missing_const_for_fn)]
+    #[must_use = "has no effect if not built"]
     pub fn identify_properties(mut self, identify_properties: IdentifyProperties) -> Self {
         self.0.identify_properties = Some(identify_properties);
 
@@ -338,6 +343,7 @@ impl ShardBuilder {
     /// # Ok(()) }
     ///
     /// ```
+    #[must_use = "has no effect if not built"]
     pub fn presence(mut self, presence: UpdatePresencePayload) -> Self {
         self.0.presence.replace(presence);
 
@@ -355,12 +361,27 @@ impl ShardBuilder {
     ///
     /// [`Cluster`]: crate::cluster::Cluster
     /// [`queue`]: crate::queue
+    #[must_use = "has no effect if not built"]
     pub fn queue(mut self, queue: Arc<dyn Queue>) -> Self {
         self.0.queue = queue;
 
         self
     }
 
+    /// Set whether or not outgoing payloads will be ratelimited.
+    ///
+    /// Useful when running behind a proxy gateway. Running without a
+    /// functional ratelimiter **will** get you ratelimited.
+    ///
+    /// Defaults to being enabled.
+    #[allow(clippy::missing_const_for_fn)]
+    #[must_use = "has no effect if not built"]
+    pub fn ratelimit_payloads(mut self, ratelimit_payloads: bool) -> Self {
+        self.0.ratelimit_payloads = ratelimit_payloads;
+
+        self
+    }
+
     /// Set the shard ID to connect as, and the total number of shards used by
     /// the bot.
     ///
