@@ -28,6 +28,7 @@ pub struct Config {
     pub(crate) session_id: Option<Box<str>>,
     pub(crate) sequence: Option<u64>,
     pub(crate) tls: Option<TlsContainer>,
+    pub(crate) ratelimit_payloads: bool,
 }
 
 impl Config {
@@ -73,6 +74,11 @@ impl Config {
         self.presence.as_ref()
     }
 
+    /// Whether or not payload ratelimiting is enabled.
+    pub const fn ratelimit_payloads(&self) -> bool {
+        self.ratelimit_payloads
+    }
+
     /// The shard's ID and the total number of shards used by the bot.
     pub const fn shard(&self) -> [u64; 2] {
         self.shard
